@@ -1,12 +1,12 @@
 /*
 
-Apache2 - Mod_bw v0.91
+Apache2 - Mod_bw v0.92
 
 Author       : Ivan Barrera A. (Bruce)
 
 HomePage     : Http://Ivn.cl/apache
 
-Release Date : 27-May-2010
+Release Date : 20-Jul-2010
 
 Status       : Stable
 
@@ -36,6 +36,7 @@ Limitations  : This mod doesn't know how fast the client is
 
 Changelog :
 
+2010-07-20 : Fixed ap_get_server_banner unknown on older apache version
 2010-05-27 : Fixed weird behaviour on Windows Hosts. (mod_bw.txt)
              Added high resolution timers for windows. (speed improvements)
 			 Fixed stupid bug that caused crash when mod is enabled but there is
@@ -47,7 +48,7 @@ Changelog :
 
 */
 
-#define VERSION "0.91"
+#define VERSION "0.92"
 
 #include "apr_version.h"
 #include "apr_buckets.h"
@@ -90,6 +91,11 @@ Changelog :
     #define AP_REG_ICASE REG_ICASE
 #endif
 
+/* Compatibility with obsolete ap_get_server_version() */
+#if !AP_MODULE_MAGIC_AT_LEAST(20051115,4)
+   #define ap_get_server_banner ap_get_server_version
+#endif
+
 /* Compatibility for APR < 1 */
 #if ( defined(APR_MAJOR_VERSION) && (APR_MAJOR_VERSION < 1) )
     #define apr_atomic_inc32 apr_atomic_inc
@@ -815,7 +821,7 @@ static int callback(request_rec * r)
     ap_rputs("  </H1>\n", r);
     ap_rputs("  <P>\n", r);
     ap_rprintf(r, "  Apache HTTP Server version: \"%s\"\n",
-            ap_get_server_banner());
+               ap_get_server_banner());
     ap_rputs("  <BR>\n", r);
     ap_rprintf(r, "  Server built: \"%s\"\n", ap_get_server_built());
     ap_rputs("  </P>\n", r);;
